# -*- coding: utf-8 -*-

'''
Settings and stuff.
'''

BASE_URL = 'https://swapi.dev/api'
PEOPLE = '/people/'
PLANETS = '/planets/'
STARSHIPS = '/starships/'
VEHICLES = '/vehicles/'
FILMS = '/films/'
SPECIES = '/species/'
SEARCH = '?search='
